Crate dompa

Crate dompa 

Structs

BlockNode
FragmentNode
TextNode
VoidNode

Enums

Node
NodeAttrVal

Functions

nodes
Transforms a given html string into a node tree.
to_html
Transform the given nodes node tree into a HTML string.
to_json
Transform the given nodes node tree into a JSON string.
traverse
Traverses the given nodes node tree and returns an updated tree based on callable. The callable must return a Node if you wish to either replace the node or update it, and return None if you wish to remove it.